aboutsummaryrefslogtreecommitdiff
path: root/scripts
diff options
context:
space:
mode:
authorKarel Kočí <cynerd@email.cz>2015-05-06 17:28:39 +0200
committerKarel Kočí <cynerd@email.cz>2015-05-06 17:28:39 +0200
commit015979b483011be86bdb10e5ca0fa7d88695b856 (patch)
treea0602c68f597c93c3070fbcdcd9d6834a83eaa51 /scripts
parent54cb72fb00801a4f2590261f96689b23e0079900 (diff)
downloadlinux-conf-perf-015979b483011be86bdb10e5ca0fa7d88695b856.tar.gz
linux-conf-perf-015979b483011be86bdb10e5ca0fa7d88695b856.tar.bz2
linux-conf-perf-015979b483011be86bdb10e5ca0fa7d88695b856.zip
Fix some comments and if in solution
These changes were forgotten after change from minisat to picosat
Diffstat (limited to 'scripts')
-rw-r--r--scripts/solution.py12
1 files changed, 3 insertions, 9 deletions
diff --git a/scripts/solution.py b/scripts/solution.py
index ee1c043..60e9538 100644
--- a/scripts/solution.py
+++ b/scripts/solution.py
@@ -10,13 +10,7 @@ from exceptions import NoSolution
def generate():
"""Collect boolean equations from files: rules, solved and required
- And get solution with minisat
-
- Relevant configurations
- rules_file
- solver_file
- required_file
- solution_file
+ And get solution with picosat
"""
# Check if rules_file exist. If it was generated.
if not os.path.isfile(sf(conf.rules_file)):
@@ -52,8 +46,8 @@ def generate():
w_file.close()
- # Execute minisat
- if conf.minisat_output:
+ # Execute picosat
+ if conf.picosat_output:
subprocess.call([conf.picosat, w_file.name, '-o',
sf(conf.solution_file)] + conf.picosat_args)
else: